Learn R Programming

woylier (version 0.0.9)

calculate_angles: Calculate angles of required rotations to map Wz to Wa

Description

Calculate angles of required rotations to map Wz to Wa

Usage

calculate_angles(Wa, Wz)

Value

named list of angles

Arguments

Wa

starting preprojected frame

Wz

target preprojected frame