Learn R Programming

woylier (version 0.0.9)

givens_rotation: It implements series of Givens rotations that maps Wa to Wz

Description

It implements series of Givens rotations that maps Wa to Wz

Usage

givens_rotation(Wa, angles, stepfraction)

Value

Givens path by stepfraction in pre-projected space

Arguments

Wa

starting preprojected frame

angles

angles of required rotations to map Wz to Wa

stepfraction

for the interpolation of rotations