Learn R Programming

woylier (version 0.0.9)

row_rot: Takes i and k-th row of a matrix and rotate matrix by theta angle (requires matrix a to be 2*q matrix)

Description

Takes i and k-th row of a matrix and rotate matrix by theta angle (requires matrix a to be 2*q matrix)

Usage

row_rot(a, i, k, theta)

Value

rotated matrix a refer to Algorithm 5.1.6 of Matrix computation (Golub, Van)

Arguments

a

matrix

i

row

k

row that we want to zero the element

theta

angle between them