Generates the interpolation in the form needed for tourr, modelled on geodesic_path()
givens_path(current, target, frozen = NULL, ...)A function with single parameter in [0, 1] that returns an interpolated frame between the current and future frames. 0 gives the current plane, 1 gives the new target frame in plane of current frame.
The distance, in radians, between the current and target frames.
The current frame.
The new target frame.
The principle angles between the current and target frames.
The current plane.
The target plane.
starting frame
target frame
indicator whether some dimensions fixed
arguments sent to later functions