powered by
Create a guided tour with Givens interpolation
guided_tour_givens( index_f, d = 2, alpha = 0.5, cooling = 0.99, max.tries = 25, max.i = Inf, optim = "search_geodesic", n_sample = 100, ... )
creates guided tour
the index function to optimize.
target dimensionality
the initial size of the search window, in radians
the amount the size of the search window should be adjusted by after each step
the maximum number of unsuccessful attempts to find a better projection before giving up
the maximum index value, stop search if a larger value is found
character indicating the search strategy to use: search_geodesic, search_better, search_better_random, search_polish. Default is search_geodesic.
search_geodesic
search_better
search_better_random
search_polish
number of samples to generate if search_f is search_polish
search_f
arguments sent to the search_f
data(sine_curve) tourr::animate_xy(sine_curve, guided_tour_givens(tourr::splines2d()), sphere=FALSE)
Run the code above in your browser using DataLab