Learn R Programming

woylier (version 0.0.9)

woylier-package: woylier: Alternative Tour Frame Interpolation Method

Description

logo

This method generates a tour path by interpolating between d-D frames in p-D using Givens rotations. The algorithm arises from the problem of zeroing elements of a matrix. This interpolation method is useful for showing specific d-D frames in the tour, as opposed to d-D planes, as done by the geodesic interpolation. It is useful for projection pursuit indexes which are not s invariant. See more details in Buj, Cook, Asimov and Hurley (2005) tools:::Rd_expr_doi("10.1016/S0169-7161(04)24014-7") and Batsaikhan, Cook and Laa (2023) tools:::Rd_expr_doi("10.48550/arXiv.2311.08181").

Arguments

Author

Maintainer: Dianne Cook dicook@monash.edu (ORCID)

Authors:

See Also